@@ -63,7 +63,7 @@ namespace ktdebug
 			{
 				Uint32 size = i == num_chunks - 1 && tor.getFileLength() % tor.getChunkSize() > 0 ?
 						tor.getFileLength() % tor.getChunkSize() : (Uint32)tor.getChunkSize();
-				fptr.seek(File::BEGIN,i*tor.getChunkSize());
+				fptr.seek(File::BEGIN,(Int64)i*tor.getChunkSize());
 				fptr.read(buf,size);
 				SHA1Hash h = SHA1Hash::generate(buf,size);
 				bool ok = (h == tor.getHash(i));
