@@ -202,7 +202,6 @@ void KTorrentView::setCurrentGroup(Group* group)
 	else
 		setCaption(i18n("All Torrents %1/%2").arg(running).arg(total));
 	
-	onSelectionChanged();
 	onExecuted(view->currentItem());
 }
 
@@ -370,7 +369,7 @@ void KTorrentView::removeDownloads()
 		{	
 			const TorrentStats & s = tc->getStats();
 			bool data_to = false;
-			if (!s.completed)
+			if (s.bytes_left_to_download > 0)
 			{
 				QString msg = i18n("The torrent %1 has not finished downloading, "
 						"do you want to delete the incomplete data, too?").arg(s.torrent_name);
@@ -549,7 +548,6 @@ void KTorrentView::update()
 			setCaption(QString("%1 %2/%3").arg(current_group->groupName()).arg(running).arg(total));
 		else
 			setCaption(i18n("All Torrents %1/%2").arg(running).arg(total));
-		onSelectionChanged();
 	}
 	
 	view->sort();
@@ -563,8 +561,8 @@ bool KTorrentView::acceptDrag(QDropEvent* event) const
 
 void KTorrentView::onSelectionChanged()
 {
-	int flags = 0;
-	
+	bool en_start = false;
+	bool en_stop = false;
 	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
@@ -575,28 +573,13 @@ void KTorrentView::onSelectionChanged()
 		{
 			const TorrentStats & s = tc->getStats();
 			if (!s.running)
-				flags |= START;
+				en_start = true;
 			else
-				flags |= STOP;
-			
-			if (flags & (START|STOP))
-				break;
+				en_stop = true;
 		}
 	}
 	
-	if (sel.count() > 0)
-		flags |= REMOVE;
-	
-	if (sel.count() == 1)
-		flags |= SCAN;
-	
-	if (running > 0)
-		flags |= STOP_ALL;
-	
-	if (running == 0 && total > 0)
-		flags |= START_ALL;
-	
-	updateActions(flags);
+	updateActions(en_start,en_stop,sel.count() > 0,sel.count() == 1);
 }
 
 void KTorrentView::queueSlot()
@@ -748,7 +731,7 @@ void KTorrentView::setDownloadLocationSlot()
 		if (tc)
 		{
 			QString dn;
-			dn = KFileDialog::getExistingDirectory(tc->getStats().output_path, this, i18n("Choose download location for %1").arg(tc->getStats().torrent_name));
+			dn = KFileDialog::getExistingDirectory(QString::null, this, i18n("Choose download location for %1").arg(tc->getStats().torrent_name));
 								
 			if(dn.isNull() || dn.isEmpty())
 				continue;
