@@ -21,8 +21,23 @@
 #define KTCOREINTERFACE_H
 
 #include <kurl.h>
+#include <qobject.h>
 #include <util/constants.h>
+#include <torrent/queuemanager.h>
 
+///Stats struct
+struct CurrentStats
+{
+	bt::Uint32 download_speed;
+	bt::Uint32 upload_speed;
+	bt::Uint64 bytes_downloaded;
+	bt::Uint64 bytes_uploaded;
+};
+
+namespace bt
+{
+	class QueueManager;
+}
 namespace kt
 {
 	class TorrentInterface;
@@ -35,8 +50,9 @@ namespace kt
 	 * the applications core, the core is responsible for managing all
 	 * TorrentControl objects.
 	*/
-	class CoreInterface
+	class CoreInterface : public QObject
 	{
+		Q_OBJECT
 	public:
 		CoreInterface();
 		virtual ~CoreInterface();
@@ -47,6 +63,11 @@ namespace kt
 		 */
 		virtual void setMaxDownloads(int max) = 0;
 	
+		virtual void setMaxSeeds(int max) = 0;
+
+		virtual void setMaxDownloadSpeed(int v) = 0;
+		virtual void setMaxUploadSpeed(int v) = 0;
+
 		/**
 		 * Set wether or not we should keep seeding after
 		 * a download has finished.
@@ -96,6 +117,10 @@ namespace kt
 		 */
 		virtual void queue(kt::TorrentInterface* tc) = 0;
 
+		virtual bt::QueueManager* getQueueManager() = 0;
+
+		virtual CurrentStats getStats() = 0;
+
 		/**
 		 * Switch the port when no torrents are running.
 		 * @param port The new port
@@ -116,7 +141,7 @@ namespace kt
 		 * @param savedir Dir to save the data
 		 * @param silently Wether or not to do this silently
 		 */
-		virtual void load(const QString & file,const QString & savedir,bool silently) = 0;
+		virtual bool load(const QString & file,const QString & savedir,bool silently) = 0;
 
 		/**
 		 * Load a torrent file. Pops up an error dialog
@@ -187,6 +212,45 @@ namespace kt
 		 * No torrents will be automatically started/stopped.
 		 */
 		virtual void setPausedState(bool pause) = 0;
+		
+		/// Get the global share ratio limit
+		virtual float getGlobalMaxShareRatio() const = 0; 
+		
+	signals:
+		/**
+		 * Seeing that when load returns the loading process may not have finished yet,
+		 * and some code expects this. We emit this signal to notify that code of it.
+		 * @param url The url which has been loaded
+		 * @param success Wether or not it succeeded
+		 * @param canceled Wether or not it was canceled by the user
+		 */
+		void loadingFinished(const KURL & url,bool success,bool canceled);
+		
+		/**
+		 * A TorrentInterface was added
+		 * @param tc 
+		 */
+		void torrentAdded(kt::TorrentInterface* tc);
+
+	
+		/**
+		 * A TorrentInterface was removed
+		 * @param tc
+		 */
+		void torrentRemoved(kt::TorrentInterface* tc);
+		
+		/**
+		 * A TorrentInterface has finished downloading.
+		 * @param tc
+		 */
+		void finished(kt::TorrentInterface* tc);
+
+    	/**
+		 * Torrent download is stopped by error
+		 * @param tc TorrentInterface
+		 * @param msg Error message
+		 */
+		void torrentStoppedByError(kt::TorrentInterface* tc, QString msg);
 	};
 
 }
