@@ -42,7 +42,7 @@ namespace dht
 	class DBItem
 	{
 		bt::Uint8 item[6];
-		bt::Uint32 time_stamp;
+		bt::TimeStamp time_stamp;
 	public:
 		DBItem();
 		DBItem(const bt::Uint8* ip_port);
@@ -50,7 +50,7 @@ namespace dht
 		virtual ~DBItem();
 		
 		/// See if the item is expired
-		bool expired(bt::Uint32 now) const;
+		bool expired(bt::TimeStamp now) const;
 		
 		/// Get the data of an item
 		const bt::Uint8* getData() const {return item;}
@@ -68,7 +68,7 @@ namespace dht
 	class Database
 	{		
 		bt::PtrMap<dht::Key,DBItemList> items;
-		QMap<dht::Key,bt::Uint32> tokens;
+		QMap<dht::Key,bt::TimeStamp> tokens;
 	public:
 		Database();
 		virtual ~Database();
@@ -97,7 +97,7 @@ namespace dht
 		 * @param now The time it is now 
 		 * (we pass this along so we only have to calculate it once)
 		 */
-		void expire(bt::Uint32 now);
+		void expire(bt::TimeStamp now);
 		
 		/**
 		 * Generate a write token, which will give peers write access to
@@ -120,7 +120,7 @@ namespace dht
 		/// Test wether or not the DB contains a key
 		bool contains(const dht::Key & key) const;
 		
-		/// Insert an empty item (only if it isn't allready in the DB)
+		/// Insert an empty item (only if it isn't already in the DB)
 		void insert(const dht::Key & key);
 	};
 
