@@ -38,7 +38,7 @@
 #include <sys/filio.h>
 #endif
 
-#if defined(Q_OS_MACX) || defined(Q_OS_DARWIN) || (defined(Q_OS_FREEBSD) && __FreeBSD_version < 600020) || defined (Q_OS_SOLARIS) || defined(Q_OS_NETBSD) 
+#ifndef MSG_NOSIGNAL
 #define MSG_NOSIGNAL 0
 #endif
 
@@ -56,7 +56,7 @@ namespace net
 
 	Socket::Socket(int fd) : m_fd(fd),m_state(IDLE)
 	{
-#if defined(Q_OS_MACX) || defined(Q_OS_DARWIN) || (defined(Q_OS_FREEBSD) && __FreeBSD_version < 600020)
+#if defined(Q_OS_MACX) || defined(Q_OS_DARWIN) || (defined(Q_OS_FREEBSD) && !defined(__DragonFly__) && __FreeBSD_version < 600020)
 		int val = 1; 
 		if (setsockopt(m_fd,SOL_SOCKET,SO_NOSIGPIPE,&val,sizeof(int)) < 0)
 		{
@@ -74,7 +74,7 @@ namespace net
 			Out(SYS_GEN|LOG_IMPORTANT) << QString("Cannot create socket : %1").arg(strerror(errno)) << endl;
 		}
 		m_fd = fd;
-#if defined(Q_OS_MACX) || defined(Q_OS_DARWIN) || (defined(Q_OS_FREEBSD) && __FreeBSD_version < 600020)
+#if defined(Q_OS_MACX) || defined(Q_OS_DARWIN) || (defined(Q_OS_FREEBSD) && !defined(__DragonFly__) && __FreeBSD_version < 600020)
 		int val = 1;
 		if (setsockopt(m_fd,SOL_SOCKET,SO_NOSIGPIPE,&val,sizeof(int)) < 0)
 		{
@@ -86,13 +86,17 @@ namespace net
 	Socket::~Socket()
 	{
 		if (m_fd >= 0)
+		{
+			shutdown(m_fd, SHUT_RDWR);
 			::close(m_fd);
+		}
 	}
 	
 	void Socket::close()
 	{
 		if (m_fd >= 0)
 		{
+			shutdown(m_fd, SHUT_RDWR);
 			::close(m_fd);
 			m_fd = -1;
 			m_state = CLOSED;
@@ -258,17 +262,17 @@ namespace net
 		return sfd;
 	}
 	
-	bool Socket::setTOS(char type_of_service)
+	bool Socket::setTOS(unsigned char type_of_service)
 	{
 #if defined(Q_OS_MACX) || defined(Q_OS_DARWIN) || (defined(Q_OS_FREEBSD) && __FreeBSD_version < 600020) || defined(Q_OS_NETBSD) || defined(Q_OS_BSD4)
-		int c = type_of_service;
+		unsigned int c = type_of_service;
 #else
-		char c = type_of_service;
+		unsigned char c = type_of_service;
 #endif
 		if (setsockopt(m_fd,IPPROTO_IP,IP_TOS,&c,sizeof(c)) < 0)
 		{
 			Out(SYS_CON|LOG_NOTICE) << QString("Failed to set TOS to %1 : %2")
-					.arg((int)type_of_service).arg(strerror(errno)) << endl;
+					.arg(type_of_service).arg(strerror(errno)) << endl;
 			return false;
 		}
 		return true;
