@@ -31,11 +31,12 @@ namespace bt
 	/**
 	 * @author Joris Guisson
 	 *
-	 * Interface for classes which wish to recieve the output from a BEncoder.
+	 * Interface for classes which wish to receive the output from a BEncoder.
 	 */
 	class BEncoderOutput
 	{
 	public:
+		virtual ~BEncoderOutput() {}
 		/**
 		 * Write a string of characters.
 		 * @param str The string
