@@ -93,11 +93,23 @@ namespace bt
 			for(Uint32 i=0; i<tor.getNumFiles(); ++i)
 			{
 				bt::TorrentFile & file = tor.getFile(i);
-				if (file.isMultimedia() && file.getPriority() != bt::ONLY_SEED_PRIORITY) 
+				if (!file.isMultimedia() || file.getPriority() == bt::ONLY_SEED_PRIORITY) 
+					continue;
+
+				if (file.getFirstChunk() == file.getLastChunk())
 				{
-					prioritise(file.getFirstChunk(), file.getFirstChunk()+1, PREVIEW_PRIORITY);
-					if (file.getLastChunk() - file.getFirstChunk() > 2)
-						prioritise(file.getLastChunk() -1,file.getLastChunk(), PREVIEW_PRIORITY);
+					// prioritise whole file 
+					prioritise(file.getFirstChunk(),file.getLastChunk(),PREVIEW_PRIORITY);
+				}
+				else
+				{
+					Uint32 chunkOffset;
+					chunkOffset = ((file.getLastChunk() - file.getFirstChunk()) / 100) + 1;
+					prioritise(file.getFirstChunk(), file.getFirstChunk()+chunkOffset, PREVIEW_PRIORITY);
+					if (file.getLastChunk() - file.getFirstChunk() > chunkOffset)
+					{
+						prioritise(file.getLastChunk() - chunkOffset, file.getLastChunk(), PREVIEW_PRIORITY);
+					}
 				}
 			}
 		}
@@ -105,10 +117,14 @@ namespace bt
 		{
 			if(tor.isMultimedia())
 			{
-				prioritise(0,1,PREVIEW_PRIORITY);
-				if (tor.getNumChunks() > 2)
-					prioritise(tor.getNumChunks() - 2,tor.getNumChunks() - 1,PREVIEW_PRIORITY);
-				//this->prioritise(getNumChunks()-2, getNumChunks()-1);
+				Uint32 chunkOffset;
+				chunkOffset = (tor.getNumChunks() / 100) + 1;
+
+				prioritise(0,chunkOffset,PREVIEW_PRIORITY);
+				if (tor.getNumChunks() > chunkOffset)
+				{
+					prioritise(tor.getNumChunks() - chunkOffset, tor.getNumChunks() - 1,PREVIEW_PRIORITY);
+				}
 			}
 		}
 	}
@@ -132,6 +148,11 @@ namespace bt
 		file_priority_file = data_dir + "file_priority";
 	}
 	
+	void ChunkManager::moveDataFiles(const QString & ndir)
+	{
+		cache->moveDataFiles(ndir);
+	}
+	
 	void ChunkManager::changeOutputPath(const QString & output_path)
 	{
 		cache->changeOutputPath(output_path);
@@ -607,25 +628,26 @@ namespace bt
 			return;
 		}
 
-		QValueList<Uint32> dnd;
+		// first write the number of excluded ones
+		// don't know this yet, so write 0 for the time being
+		Uint32 tmp = 0;
+		fptr.write(&tmp,sizeof(Uint32));
 		
 		Uint32 i = 0;
+		Uint32 cnt = 0;
 		while (i < tor.getNumFiles())
 		{
 			if (tor.getFile(i).doNotDownload())
-				dnd.append(i);
+			{
+				fptr.write(&i,sizeof(Uint32));
+				cnt++;
+			}
 			i++;
 		}
 
-		// first write the number of excluded ones
-		Uint32 tmp = dnd.count();
-		fptr.write(&tmp,sizeof(Uint32));
-		// then all the excluded ones
-		for (i = 0;i < dnd.count();i++)
-		{
-			tmp = dnd[i];
-			fptr.write(&tmp,sizeof(Uint32));
-		}
+		// go back to the beginning and write the number of files
+		fptr.seek(File::BEGIN,0);
+		fptr.write(&cnt,sizeof(Uint32));
 		fptr.flush();
 	}
 	
@@ -679,26 +701,29 @@ namespace bt
 
 		try
 		{
-			QValueList<Uint32> dnd;
-			
-			Uint32 i = 0;
-			for ( ; i < tor.getNumFiles(); i++)
-			{
-				if(tor.getFile(i).getPriority() != NORMAL_PRIORITY)
-				{
-					dnd.append(i);
-					dnd.append(tor.getFile(i).getPriority());
-				}
-			}
-	
-			Uint32 tmp = dnd.count();
+			// first write the number of excluded ones
+			// don't know this yet, so write 0 for the time being
+			Uint32 tmp = 0;
 			fptr.write(&tmp,sizeof(Uint32));
-			// write all the non-default priority ones
-			for (i = 0;i < dnd.count();i++)
+		
+			Uint32 i = 0;
+			Uint32 cnt = 0;
+			while (i < tor.getNumFiles())
 			{
-				tmp = dnd[i];
-				fptr.write(&tmp,sizeof(Uint32));
+				const TorrentFile & tf = tor.getFile(i);
+				if (tf.getPriority() != NORMAL_PRIORITY)
+				{
+					tmp = tf.getPriority();
+					fptr.write(&i,sizeof(Uint32));
+					fptr.write(&tmp,sizeof(Uint32));
+					cnt+=2;
+				}
+				i++;
 			}
+
+			// go back to the beginning and write the number of items
+			fptr.seek(File::BEGIN,0);
+			fptr.write(&cnt,sizeof(Uint32));
 			fptr.flush();
 		}
 		catch (bt::Error & err)
@@ -791,9 +816,15 @@ namespace bt
 			// if it is a multimedia file, prioritise first and last chunks of file
 			if (tf->isMultimedia())
 			{
-				prioritise(first,first+1,PREVIEW_PRIORITY);
+				Uint32 chunkOffset;
+				chunkOffset = ((last - first) / 100) + 1;
+
+				prioritise(first,first+chunkOffset,PREVIEW_PRIORITY);
 				if (last - first > 2)
-					prioritise(last -1,last, PREVIEW_PRIORITY);
+				{
+					prioritise(last - chunkOffset, last, PREVIEW_PRIORITY);
+					//prioritise(last -1,last, PREVIEW_PRIORITY);
+				}
 			}
 		}
 		else
