@@ -22,6 +22,7 @@
 #include <qstringlist.h>
 #include <qfileinfo.h>
 #include <klocale.h>
+#include <kio/netaccess.h>
 #include <util/file.h>
 #include <util/fileops.h>
 #include <util/functions.h>
@@ -35,6 +36,7 @@
 #include "cachefile.h"
 #include "dndfile.h"
 #include "preallocationthread.h"
+#include "movedatafilesjob.h"
 
 
 
@@ -42,6 +44,7 @@ namespace bt
 {
 	static Uint64 FileOffset(Chunk* c,const TorrentFile & f,Uint64 chunk_size);
 	static Uint64 FileOffset(Uint32 cindex,const TorrentFile & f,Uint64 chunk_size);
+	static void DeleteEmptyDirs(const QString & output_dir,const QString & fpath);
 
 
 	MultiFileCache::MultiFileCache(Torrent& tor,const QString & tmpdir,const QString & datadir,bool custom_output_name) : Cache(tor, tmpdir,datadir)
@@ -182,11 +185,68 @@ namespace bt
 			if (!tf.doNotDownload())
 			{
 				QString fpath = tf.getPath();
-				bt::Delete(cache_dir + fpath,true); // delete any existing symlinks
-				bt::SymLink(output_dir + fpath,cache_dir + fpath,true); // create new one
+				if (bt::Exists(output_dir + fpath))
+				{
+					bt::Delete(cache_dir + fpath,true); // delete any existing symlinks
+					// create new one
+					bt::SymLink(output_dir + fpath,cache_dir + fpath,true); 
+				}
 			}
 		}
 	}
+	
+	void MultiFileCache::moveDataFiles(const QString & ndir)
+	{
+		if (!bt::Exists(ndir))
+			bt::MakeDir(ndir);
+		
+		QString nd = ndir;
+		if (!nd.endsWith(bt::DirSeparator()))
+			nd += bt::DirSeparator();
+		
+		try
+		{
+			MoveDataFilesJob* mvd = new MoveDataFilesJob();
+			for (Uint32 i = 0;i < tor.getNumFiles();i++)
+			{			
+				TorrentFile & tf = tor.getFile(i);
+				if (tf.doNotDownload())
+					continue;
+				
+				// check if every directory along the path exists, and if it doesn't
+				// create it
+				QStringList sl = QStringList::split(bt::DirSeparator(),nd + tf.getPath());
+				QString odir = bt::DirSeparator();
+				for (Uint32 i = 0;i < sl.count() - 1;i++)
+				{
+					odir += sl[i] + bt::DirSeparator();
+					if (!bt::Exists(odir))
+					{
+						bt::MakeDir(odir);
+					}
+				}
+				
+				mvd->addMove(output_dir + tf.getPath(),nd + tf.getPath());
+			}
+			
+			mvd->startMoving();
+			if (KIO::NetAccess::synchronousRun(mvd,0))
+			{
+				for (Uint32 i = 0;i < tor.getNumFiles();i++)
+				{
+					TorrentFile & tf = tor.getFile(i);
+					// check for empty directories and delete them 
+					DeleteEmptyDirs(output_dir,tf.getPath());
+				}
+			}
+			else
+				throw bt::Error("Move failed");
+		}
+		catch (bt::Error & err)
+		{
+			throw; // rethrow error
+		}
+	}
 
 	void MultiFileCache::create()
 	{
@@ -272,7 +332,7 @@ namespace bt
 			if (!fd)
 				return;
 			
-			if (Cache::mappedModeAllowed())
+			if (Cache::mappedModeAllowed() && mmap_failures < 3)
 			{
 				Uint64 off = FileOffset(c,f,tor.getChunkSize());
 				Uint8* buf = (Uint8*)fd->map(c,off,c->getSize(),CacheFile::READ);
@@ -283,6 +343,8 @@ namespace bt
 					// if mmap fails we will just load it buffered
 					return;
 				}
+				else
+					mmap_failures++;
 			}
 		}
 		
@@ -348,8 +410,12 @@ namespace bt
 			Uint64 off = FileOffset(c,tor.getFile(tflist.first()),tor.getChunkSize());
 			CacheFile* fd = files.find(tflist.first());
 			Uint8* buf = 0;
-			if (fd && Cache::mappedModeAllowed())
+			if (fd && Cache::mappedModeAllowed() && mmap_failures < 3)
+			{
 				buf = (Uint8*)fd->map(c,off,c->getSize(),CacheFile::RW);
+				if (!buf)
+					mmap_failures++;
+			}
 			
 			if (!buf)
 			{
@@ -706,7 +772,7 @@ namespace bt
 			{
 				// no childern so delete the directory
 				Out(SYS_GEN|LOG_IMPORTANT) << "Deleting empty directory : " << path << endl;
-				bt::Delete(path);
+				bt::Delete(path,true);
 				sl.pop_back(); // remove the last so we can go one higher
 			}
 			else
@@ -725,7 +791,7 @@ namespace bt
 		if (el.count() == 0)
 		{
 			Out(SYS_GEN|LOG_IMPORTANT) << "Deleting empty directory : " << output_dir << endl;
-			bt::Delete(output_dir);
+			bt::Delete(output_dir,true);
 		}
 	}
 	
@@ -734,12 +800,12 @@ namespace bt
 		for (Uint32 i = 0;i < tor.getNumFiles();i++)
 		{
 			TorrentFile & tf = tor.getFile(i);
-			if (tf.doNotDownload())
-				continue;
-			
 			QString fpath = tf.getPath();
-			// first delete the file
-			bt::Delete(output_dir + fpath);
+			if (!tf.doNotDownload())
+			{
+				// first delete the file
+				bt::Delete(output_dir + fpath);
+			}
 			
 			// check for subdirectories
 			DeleteEmptyDirs(output_dir,fpath);
