@@ -20,8 +20,8 @@
 #ifndef BTPACKETWRITER_H
 #define BTPACKETWRITER_H
 
+#include <list>
 #include <qmutex.h>
-#include <qptrlist.h>
 #include <net/bufferedsocket.h>
 #include "globals.h"
 
@@ -39,7 +39,10 @@ namespace bt
 	class PacketWriter : public net::SocketWriter
 	{
 		Peer* peer;
-		QPtrList<Packet> packets;
+		std::list<Packet*> control_packets;
+		std::list<Packet*> data_packets;
+		Packet* curr_packet;
+		Uint32 ctrl_packets_sent;
 		mutable Uint32 uploaded;
 		mutable Uint32 uploaded_non_data;
 		mutable QMutex mutex;
@@ -137,19 +140,42 @@ namespace bt
 		 * @param index Index of the chunk
 		 */
 		void sendSuggestPiece(Uint32 index);
+		
+		/// Send the extension protocol handshake
+		void sendExtProtHandshake(Uint16 port,bool pex_on = true);
+		
+		/// Send an extended protocol message
+		void sendExtProtMsg(Uint8 id,const QByteArray & data);
 
 		/// Get the number of packets which need to be written
 		Uint32 getNumPacketsToWrite() const;
 		
+		/// Get the number of data packets to write
+		Uint32 getNumDataPacketsToWrite() const;
+		
 		/// Get the number of data bytes uploaded
 		Uint32 getUploadedDataBytes() const;
 		
 		/// Get the number of bytes uploaded
 		Uint32 getUploadedNonDataBytes() const;
 
+		/**
+		 * Do not send a piece which matches this request.
+		 * But only if we are not allready sending the piece.
+		 * @param req The request
+		 * @param reject Wether we can send a reject instead
+		 */
+		void doNotSendPiece(const Request & req,bool reject);
+		
+		/**
+		 * Clear all pieces we are not in the progress of sending.
+		 * @param reject Send a reject packet
+		 */
+		void clearPieces(bool reject);
 	
 	private:
 		void queuePacket(Packet* p);
+		Packet* selectPacket();
 		virtual Uint32 onReadyToWrite(Uint8* data,Uint32 max_to_write);
 		virtual bool hasBytesToWrite() const;
 	};
