@@ -19,9 +19,12 @@
  ***************************************************************************/
 #include <qdir.h>
 #include <qhostaddress.h>
+#include <errno.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <sys/time.h>
+#include <sys/resource.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <netdb.h>
@@ -31,6 +34,7 @@
 #include <kglobal.h>
 #include "functions.h"
 #include "error.h"
+#include "log.h"
 
 namespace bt
 {
@@ -162,14 +166,72 @@ namespace bt
 	{
 		return (Int16)(buf[off] << 8) | buf[off + 1];
 	}
-
-	Uint32 GetCurrentTime()
+	
+	void UpdateCurrentTime()
+	{
+		global_time_stamp = Now();
+	}
+	
+	TimeStamp global_time_stamp = 0;
+	
+	Uint64 Now()
 	{
 		struct timeval tv;
 		gettimeofday(&tv,0);
-		return (Uint32)(tv.tv_sec * 1000 + tv.tv_usec * 0.001);
+		global_time_stamp = (Uint64)(tv.tv_sec * 1000 + tv.tv_usec * 0.001);
+		return global_time_stamp;
+	}
+	
+	Uint32 MaxOpenFiles()
+	{
+		struct rlimit lim;
+		getrlimit(RLIMIT_NOFILE,&lim);
+		return lim.rlim_cur;
 	}
 
+	bool MaximizeLimits()
+	{
+		// first get the current limits
+		struct rlimit lim;
+		getrlimit(RLIMIT_NOFILE,&lim);
+		
+		if (lim.rlim_cur != lim.rlim_max)
+		{
+			Out(SYS_GEN|LOG_DEBUG) << "Current limit for number of files : " << lim.rlim_cur 
+					<< " (" << lim.rlim_max << " max)" << endl;
+			lim.rlim_cur = lim.rlim_max;
+			if (setrlimit(RLIMIT_NOFILE,&lim) < 0)
+			{
+				Out(SYS_GEN|LOG_DEBUG) << "Failed to maximize file limit : " 
+						<< QString(strerror(errno)) << endl;
+				return false;
+			}
+		}
+		else
+		{
+			Out(SYS_GEN|LOG_DEBUG) << "File limit allready at maximum " << endl;
+		}
+		
+		getrlimit(RLIMIT_DATA,&lim);
+		if (lim.rlim_cur != lim.rlim_max)
+		{
+			Out(SYS_GEN|LOG_DEBUG) << "Current limit for data size : " << lim.rlim_cur 
+					<< " (" << 	lim.rlim_max << " max)" << endl;
+			lim.rlim_cur = lim.rlim_max;
+			if (setrlimit(RLIMIT_DATA,&lim) < 0)
+			{
+				Out(SYS_GEN|LOG_DEBUG) << "Failed to maximize data limit : " 
+						<< QString(strerror(errno)) << endl;
+				return false;
+			}
+		}
+		else
+		{
+			Out(SYS_GEN|LOG_DEBUG) << "Data limit allready at maximum " << endl;
+		}
+		
+		return true;
+	}
 
 
 	
