@@ -19,6 +19,7 @@
  ***************************************************************************/
 #include <klocale.h>
 #include <kglobal.h>
+#include <kmessagebox.h>
 #include <interfaces/functions.h>
 #include <interfaces/torrentinterface.h>
 #include <interfaces/torrentfileinterface.h>
@@ -117,21 +118,18 @@ namespace kt
 		{
 			case FIRST_PRIORITY:
 				setText(2, i18n("Yes, First"));
-				setChecked(true);
 				break;
 			case LAST_PRIORITY:
 				setText(2, i18n("Yes, Last"));
-				setChecked(true);
 				break;
+			case ONLY_SEED_PRIORITY:
 			case EXCLUDED:
-				setText(2, i18n("No"));
-				setChecked(false);
+				setText(2, i18n("No"));		
 				break;
 			case PREVIEW_PRIORITY:
 				break;
 			default:
 				setText(2, i18n("Yes"));
-				setChecked(true);
 				break;
 		}
 	}
@@ -144,6 +142,25 @@ namespace kt
 			setText(2, i18n("No"));
 		}
 	}
+	
+	bt::ConfirmationResult IWFileTreeItem::confirmationDialog()
+	{
+		return bt::KEEP_DATA;
+		/*
+		QString msg = i18n("Do you want to keep the existing data for seeding ?");
+		int ret = KMessageBox::warningYesNoCancel(0,msg,QString::null,
+				KGuiItem(i18n("Keep the data")),
+				KGuiItem(i18n("Delete the data")));
+		if (ret == KMessageBox::Yes)
+			return bt::KEEP_DATA;
+		else if (ret == KMessageBox::No)
+			return bt::THROW_AWAY_DATA;
+		else
+			return bt::CANCELED;
+		*/
+	}
+	
 }
 
-#include "iwfiletreeitem.moc"
\ No newline at end of file
+#include "iwfiletreeitem.moc"
+
