@@ -23,6 +23,8 @@
 #include <kurlrequester.h>
 #include <kpushbutton.h>
 #include <kmessagebox.h>
+#include <kio/job.h>
+#include <kio/jobclasses.h>
 #include <util/log.h>
 #include <util/error.h>
 #include <util/file.h>
@@ -41,7 +43,7 @@ using namespace bt;
 namespace kt
 {
 	ImportDialog::ImportDialog(CoreInterface* core,QWidget* parent, const char* name, bool modal, WFlags fl)
-	: ImportDlgBase(parent,name, modal,fl),core(core)
+	: ImportDlgBase(parent,name, modal,fl),DataCheckerListener(false),core(core)
 	{
 		KURLRequester* r = m_torrent_url;
 		r->setMode(KFile::File|KFile::LocalOnly);
@@ -69,31 +71,16 @@ namespace kt
 		// don't care
 	}
 	
-	void ImportDialog::onImport()
+	void ImportDialog::finished()
+	{
+		// only used for check in separate thread, so does not apply for the import plugin
+	}
+	
+	void ImportDialog::import(Torrent & tor)
 	{
-		m_progress->setEnabled(true);
-		m_import_btn->setEnabled(false);
-		m_cancel_btn->setEnabled(false);
-		m_torrent_url->setEnabled(false);
-		m_data_url->setEnabled(false);
-		
 		// get the urls
 		KURL tor_url = KURL::fromPathOrURL(m_torrent_url->url());
 		KURL data_url = KURL::fromPathOrURL(m_data_url->url());
-		Torrent tor;
-		
-		// try to load the torrent
-		try
-		{
-			tor.load(tor_url.path(),false);
-		}
-		catch (Error & e)
-		{
-			KMessageBox::error(this,i18n("Cannot load the torrent file : %1").arg(e.toString()),
-							   i18n("Error"));
-			reject();
-			return;
-		}
 		
 		// now we need to check the data
 		DataChecker* dc = 0;
@@ -198,6 +185,70 @@ namespace kt
 		accept();
 	}
 	
+	void ImportDialog::onTorrentGetReult(KIO::Job* j)
+	{
+		if (j->error())
+		{
+			j->showErrorDialog(this);
+			reject();
+		}
+		else
+		{
+			KIO::StoredTransferJob* stj = (KIO::StoredTransferJob*)j;
+			Torrent tor;
+		
+			// try to load the torrent
+			try
+			{
+				tor.load(stj->data(),false);
+			}
+			catch (Error & e)
+			{
+				KMessageBox::error(this,i18n("Cannot load the torrent file : %1").arg(e.toString()),
+								   i18n("Error"));
+				reject();
+				return;
+			}
+			import(tor);
+		}
+	}
+	
+	void ImportDialog::onImport()
+	{
+		m_progress->setEnabled(true);
+		m_import_btn->setEnabled(false);
+		m_cancel_btn->setEnabled(false);
+		m_torrent_url->setEnabled(false);
+		m_data_url->setEnabled(false);
+		
+		KURL tor_url = KURL::fromPathOrURL(m_torrent_url->url());
+		if (!tor_url.isLocalFile())
+		{
+			// download the torrent file
+			KIO::StoredTransferJob* j = KIO::storedGet(tor_url);
+			connect(j,SIGNAL(result(KIO::Job* )),this,SLOT(onTorrentGetReult(KIO::Job*)));
+		}
+		else
+		{
+			KURL tor_url = KURL::fromPathOrURL(m_torrent_url->url());
+			Torrent tor;
+		
+			// try to load the torrent
+			try
+			{
+				tor.load(tor_url.path(),false);
+			}
+			catch (Error & e)
+			{
+				KMessageBox::error(this,i18n("Cannot load the torrent file : %1").arg(e.toString()),
+								   i18n("Error"));
+				reject();
+				return;
+			}
+			import(tor);
+		}
+	}
+	
 	void ImportDialog::writeIndex(const QString & file,const BitSet & chunks)
 	{
 		// first try to open it
@@ -280,6 +331,8 @@ namespace kt
 		out << "RUNNING_TIME_UL=0" << ::endl;
 		out << "PRIORITY=0" << ::endl;
 		out << "AUTOSTART=1" << ::endl;
+		if (core->getGlobalMaxShareRatio() > 0)
+			out << QString("MAX_RATIO=%1").arg(core->getGlobalMaxShareRatio(),0,'f',2) << ::endl;
 		out << QString("IMPORTED=%1").arg(imported) << ::endl;
 		if (custom_output_name)
 			out << "CUSTOM_OUTPUT_NAME=1" << endl;
