@@ -23,13 +23,14 @@
 #include <kurl.h>
 #include <qstringlist.h>
 #include <kstreamsocket.h>
-#include <util/constants.h>
+#include <net/portlist.h>
 
 using bt::Uint16;
 
 namespace bt
 {
 	class HTTPRequest;
+	class WaitJob;
 }
 
 namespace KIO
@@ -106,16 +107,11 @@ namespace kt
 		Q_OBJECT
 				
 	public:
-		enum Protocol
+		struct Forwarding 
 		{
-			UDP,TCP
-		};
-		
-		struct Forwarding
-		{
-			Uint16 port;
-			Protocol prot;
-			bool pending;
+			net::Port port;
+			bt::HTTPRequest* pending_req;
+			UPnPService* service;
 		};
 	private:	
 		QString server;
@@ -124,7 +120,6 @@ namespace kt
 		UPnPDeviceDescription desc;
 		QValueList<UPnPService> services;
 		QValueList<Forwarding> fwds;
-		QMap<bt::HTTPRequest*,QValueList<Forwarding>::iterator > reqs;
 		QValueList<bt::HTTPRequest*> active_reqs;
 	public:
 		/**
@@ -159,32 +154,32 @@ namespace kt
 		 */
 		void addService(const UPnPService & s);
 			
+#if 0
 		/**
 		 * See if a port is forwarded
 		 * @param port The Port
-		 * @param protocol UDP or TCP
 		 */
-		void isPortForwarded(Uint16 port,Protocol protocol);	
+		void isPortForwarded(const net::Port & port);	
 		
 		/**
 		 * Get the external IP address.
 		 */
 		void getExternalIP();
+#endif
 		
 		/**
 		 * Forward a local port
-		 * @param localip The local ip address
 		 * @param port The local port to forward
-		 * @param prot UDP or TCP
 		 */
-		void forward(Uint16 port,Protocol prot);
+		void forward(const net::Port & port);
 		
 		/**
 		 * Undo forwarding
 		 * @param port The port
-		 * @param prot UDP or TCP
+		 * @param waitjob When this is set the jobs needs to be added to the waitjob, 
+		 * so we can wait for their completeion at exit
 		 */
-		void undoForward(Uint16 remote,Protocol prot);
+		void undoForward(const net::Port & port,bt::WaitJob* waitjob = 0);
 		
 		void debugPrintData();
 		
@@ -206,7 +201,7 @@ namespace kt
 		void updateGUI();
 		
 		/**
-		 * Signal which indicates that the XML was downloaded succesfully or not.
+		 * Signal which indicates that the XML was downloaded successfully or not.
 		 * @param r The router which emitted the signal
 		 * @param success Wether or not it succeeded
 		 */
@@ -215,8 +210,12 @@ namespace kt
 	private:
 		QValueList<UPnPService>::iterator findPortForwardingService();		
 		
-		bt::HTTPRequest* sendSoapQuery(const QString & query,const QString & soapact,const QString & controlurl);
+		bt::HTTPRequest* sendSoapQuery(const QString & query,const QString & soapact,const QString & controlurl,bool at_exit = false);
 		bool verbose;
+		
+		void forward(UPnPService* srv,const net::Port & port);
+		void undoForward(UPnPService* srv,const net::Port & port,bt::WaitJob* waitjob);
+		void httpRequestDone(bt::HTTPRequest* r,bool erase_fwd);
 	};
 
 }
